==> xlniuxdata-vipgame-1.0.58-sources.jar: com/xunlei/niux/data/vipgame/vo/LaXinYe.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;
@Table(tableName="laxinye",pkFieldAssign=false,pkFieldName="laXinYeId")
public class LaXinYe {
	private Long laXinYeId;
	private String name;
	private String title;
	private String flashUrl;
	private String laXinYeUrl;
	private String gameId;
	private Boolean isValid;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String height;
	private String weight;
    private Boolean isWebLogin;
    private Integer autoOpenTime;
	private String laXinYeType;
    private String cfgUrl;

    private Boolean hasTop;
    private Integer saveIconTime;
    private String iconPic;
    private String iconJumpUrl;
    private String iconName;
    private String moreGameJumpUrl;

	public String getLaXinYeType() {
		return laXinYeType;
	}
	public void setLaXinYeType(String laXinYeType) {
		this.laXinYeType = laXinYeType;
	}
	public String getWeight() {
		return weight;
	}
	public void setWeight(String weight) {
		this.weight = weight;
	}
	public String getHeight() {
		return height;
	}
	public void setHeight(String height) {
		this.height = height;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Long getLaXinYeId() {
		return laXinYeId;
	}
	public void setLaXinYeId(Long laXinYeId) {
		this.laXinYeId = laXinYeId;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getFlashUrl() {
		return flashUrl;
	}
	public void setFlashUrl(String flashUrl) {
		this.flashUrl = flashUrl;
	}
	public String getLaXinYeUrl() {
		return laXinYeUrl;
	}
	public void setLaXinYeUrl(String laXinYeUrl) {
		this.laXinYeUrl = laXinYeUrl;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public Boolean getIsValid() {
		return isValid;
	}
	public void setIsValid(Boolean isValid) {
		this.isValid = isValid;
	}

    public Boolean getIsWebLogin() {
        return isWebLogin;
    }

    public void setIsWebLogin(Boolean isWebLogin) {
        this.isWebLogin = isWebLogin;
    }

    public Integer getAutoOpenTime() {
        return autoOpenTime;
    }

    public void setAutoOpenTime(Integer autoOpenTime) {
        this.autoOpenTime = autoOpenTime;
    }

    public String getCfgUrl() {
        return cfgUrl;
    }

    public void setCfgUrl(String cfgUrl) {
        this.cfgUrl = cfgUrl;
    }

    public Integer getSaveIconTime() {
        return saveIconTime;
    }

    public void setSaveIconTime(Integer saveIconTime) {
        this.saveIconTime = saveIconTime;
    }

    public String getIconPic() {
        return iconPic;
    }

    public void setIconPic(String iconPic) {
        this.iconPic = iconPic;
    }

    public String getIconJumpUrl() {
        return iconJumpUrl;
    }

    public void setIconJumpUrl(String iconJumpUrl) {
        this.iconJumpUrl = iconJumpUrl;
    }

    public String getIconName() {
        return iconName;
    }

    public void setIconName(String iconName) {
        this.iconName = iconName;
    }

    public String getMoreGameJumpUrl() {
        return moreGameJumpUrl;
    }

    public void setMoreGameJumpUrl(String moreGameJumpUrl) {
        this.moreGameJumpUrl = moreGameJumpUrl;
    }

    public Boolean getHasTop() {
        return hasTop;
    }

    public void setHasTop(Boolean hasTop) {
        this.hasTop = hasTop;
    }
}

==> xlniuxdata-vipgame-1.0.65-20160811.095854-42-sources.jar: com/xunlei/niux/data/vipgame/vo/LaXinYe.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;
@Table(tableName="laxinye",pkFieldAssign=false,pkFieldName="laXinYeId")
public class LaXinYe {
	private Long laXinYeId;
	private String name;
	private String title;
	private String flashUrl;
	private String laXinYeUrl;
	private String gameId;
	private Boolean isValid;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String height;
	private String weight;
    private Boolean isWebLogin;
    private Integer autoOpenTime;
	private String laXinYeType;
    private String cfgUrl;

    private Boolean hasTop;
    private Integer saveIconTime;
    private String iconPic;
    private String iconJumpUrl;
    private String iconName;
    private String moreGameJumpUrl;

    private Boolean isAutoReOpen;
    private Integer autoReOpenTime;
    private String autoReOpenUrl;
    private Boolean isCloseReOpen;
    private String closeReOpenUrl;
    
	public Boolean getIsAutoReOpen() {
		return isAutoReOpen;
	}
	public void setIsAutoReOpen(Boolean isAutoReOpen) {
		this.isAutoReOpen = isAutoReOpen;
	}
	public Integer getAutoReOpenTime() {
		return autoReOpenTime;
	}
	public void setAutoReOpenTime(Integer autoReOpenTime) {
		this.autoReOpenTime = autoReOpenTime;
	}
	public String getAutoReOpenUrl() {
		return autoReOpenUrl;
	}
	public void setAutoReOpenUrl(String autoReOpenUrl) {
		this.autoReOpenUrl = autoReOpenUrl;
	}
	public Boolean getIsCloseReOpen() {
		return isCloseReOpen;
	}
	public void setIsCloseReOpen(Boolean isCloseReOpen) {
		this.isCloseReOpen = isCloseReOpen;
	}
	public String getCloseReOpenUrl() {
		return closeReOpenUrl;
	}
	public void setCloseReOpenUrl(String closeReOpenUrl) {
		this.closeReOpenUrl = closeReOpenUrl;
	}
	public String getLaXinYeType() {
		return laXinYeType;
	}
	public void setLaXinYeType(String laXinYeType) {
		this.laXinYeType = laXinYeType;
	}
	public String getWeight() {
		return weight;
	}
	public void setWeight(String weight) {
		this.weight = weight;
	}
	public String getHeight() {
		return height;
	}
	public void setHeight(String height) {
		this.height = height;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Long getLaXinYeId() {
		return laXinYeId;
	}
	public void setLaXinYeId(Long laXinYeId) {
		this.laXinYeId = laXinYeId;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getFlashUrl() {
		return flashUrl;
	}
	public void setFlashUrl(String flashUrl) {
		this.flashUrl = flashUrl;
	}
	public String getLaXinYeUrl() {
		return laXinYeUrl;
	}
	public void setLaXinYeUrl(String laXinYeUrl) {
		this.laXinYeUrl = laXinYeUrl;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public Boolean getIsValid() {
		return isValid;
	}
	public void setIsValid(Boolean isValid) {
		this.isValid = isValid;
	}

    public Boolean getIsWebLogin() {
        return isWebLogin;
    }

    public void setIsWebLogin(Boolean isWebLogin) {
        this.isWebLogin = isWebLogin;
    }

    public Integer getAutoOpenTime() {
        return autoOpenTime;
    }

    public void setAutoOpenTime(Integer autoOpenTime) {
        this.autoOpenTime = autoOpenTime;
    }

    public String getCfgUrl() {
        return cfgUrl;
    }

    public void setCfgUrl(String cfgUrl) {
        this.cfgUrl = cfgUrl;
    }

    public Integer getSaveIconTime() {
        return saveIconTime;
    }

    public void setSaveIconTime(Integer saveIconTime) {
        this.saveIconTime = saveIconTime;
    }

    public String getIconPic() {
        return iconPic;
    }

    public void setIconPic(String iconPic) {
        this.iconPic = iconPic;
    }

    public String getIconJumpUrl() {
        return iconJumpUrl;
    }

    public void setIconJumpUrl(String iconJumpUrl) {
        this.iconJumpUrl = iconJumpUrl;
    }

    public String getIconName() {
        return iconName;
    }

    public void setIconName(String iconName) {
        this.iconName = iconName;
    }

    public String getMoreGameJumpUrl() {
        return moreGameJumpUrl;
    }

    public void setMoreGameJumpUrl(String moreGameJumpUrl) {
        this.moreGameJumpUrl = moreGameJumpUrl;
    }

    public Boolean getHasTop() {
        return hasTop;
    }

    public void setHasTop(Boolean hasTop) {
        this.hasTop = hasTop;
    }
}
